@@ -1,34 +1,26 @@
 import logging
-import importlib
-import scipy.sparse.linalg  # NOQA
-import numpy.linalg
+from math import ceil, pi
 
-from math import ceil
-
-from scipy.sparse import csr_matrix  # NOQA
-
-from cvxopt import matrix, spmatrix, mul, div
+from cvxopt import mul, div
 from cvxopt.lapack import gesv
 
-from .base import RoutineBase
-from andes.config.eig import Eig
-from andes.consts import pi
-from andes.formats.txt import dump_data
-from andes.utils.solver import Solver
-from andes.utils import elapsed
+from andes.io.txt import dump_data
+from andes.utils.misc import elapsed
+from andes.routines.base import BaseRoutine
+from andes.shared import np, matrix, spmatrix, plt, mpl
 
 logger = logging.getLogger(__name__)
 __cli__ = 'eig'
 
 
-class EIG(RoutineBase):
+class EIG(BaseRoutine):
     """
     Eigenvalue analysis routine
     """
-    def __init__(self, system, rc=None):
-        self.system = system
-        self.solver = Solver(system.config.sparselib)
-        self.config = Eig(rc=rc)
+    def __init__(self, system, config):
+        super().__init__(system=system, config=config)
+
+        self.config.add(plot=0)
 
         # internal flags and storages
         self.As = None
@@ -47,10 +39,10 @@ class EIG(RoutineBase):
         """
         system = self.system
 
-        Gyx = matrix(system.dae.Gx)
-        self.solver.linsolve(system.dae.Gy, Gyx)
+        gyx = matrix(system.dae.gx)
+        self.solver.linsolve(system.dae.gy, gyx)
 
-        self.As = matrix(system.dae.Fx - system.dae.Fy * Gyx)
+        self.As = matrix(system.dae.fx - system.dae.fy * gyx)
 
         # ------------------------------------------------------
         # TODO: use scipy eigs
@@ -70,7 +62,7 @@ class EIG(RoutineBase):
         -------
         None
         """
-        self.eigs = numpy.linalg.eigvals(self.As)
+        self.eigs = np.linalg.eigvals(self.As)
         # TODO: use scipy.sparse.linalg.eigs(self.As)
 
         return self.eigs
@@ -83,13 +75,14 @@ class EIG(RoutineBase):
         -------
 
         """
-        mu, N = numpy.linalg.eig(self.As)
+        mu, N = np.linalg.eig(self.As)
         # TODO: use scipy.sparse.linalg.eigs(self.As)
 
         N = matrix(N)
         n = len(mu)
         idx = range(n)
 
+        mu_complex = np.array([0] * n, dtype=complex)
         W = matrix(spmatrix(1.0, idx, idx, (n, n), N.typecode))
         gesv(N, W)
 
@@ -100,40 +93,43 @@ class EIG(RoutineBase):
         partfact = partfact.T
 
         for item in idx:
-            mu_real = mu[item].real
-            mu_imag = mu[item].imag
-            mu[item] = complex(round(mu_real, 4), round(mu_imag, 4))
+            mu_real = float(mu[item].real)
+            mu_imag = float(mu[item].imag)
+            mu_complex[item] = complex(round(mu_real, 4), round(mu_imag, 4))
             partfact[item, :] /= WN[item]
 
         # participation factor
-        self.mu = matrix(mu)
+        self.mu = matrix(mu_complex)
         self.part_fact = matrix(partfact)
 
         return self.mu, self.part_fact
 
-    def run(self):
+    def run(self, **kwargs):
         ret = False
         system = self.system
 
-        if system.pflow.solved is False:
-            logger.warning(
-                'Power flow not solved. Eig analysis will not continue.')
+        if system.PFlow.converged is False:
+            logger.warning('Power flow not solved. Eig analysis will not continue.')
             return ret
-        elif system.dae.n == 0:
+        else:
+            if system.TDS.initialized is False:
+                system.TDS._initialize()
+                system.TDS._implicit_step()
+
+        if system.dae.n == 0:
             logger.warning('No dynamic model. Eig analysis will not continue.')
             return ret
 
         t1, s = elapsed()
         logger.info('-> Eigenvalue Analysis:')
 
-        system.dae.factorize = True
-        exec(system.call.int)
-
         self.calc_state_matrix()
         self.calc_part_factor()
 
         self.dump_results()
-        self.plot_results()
+
+        if self.config.plot:
+            self.plot()
         ret = True
 
         _, s = elapsed(t1)
@@ -141,13 +137,9 @@ class EIG(RoutineBase):
 
         return ret
 
-    def plot_results(self):
-        try:
-            plt = importlib.import_module('matplotlib.pyplot')
-        except ImportError:
-            plt = None
-            logger.warning('Install matplotlib to plot eigenvalue map.')
-            return False
+    def plot(self, left=-6, right=0.5, ymin=-8, ymax=8, damping=0.05,
+             linewidth=0.5, dpi=150):
+        mpl.rc('font', family='Times New Roman', size=12)
 
         mu_real = self.mu.real()
         mu_imag = self.mu.imag()
@@ -174,12 +166,29 @@ class EIG(RoutineBase):
             logger.info(
                 'System is small-signal stable in the initial neighbourhood.')
 
-        if self.config.plot:
-            fig, ax = plt.subplots()
-            ax.scatter(n_mu_real, n_mu_imag, marker='x', s=26, color='green')
-            ax.scatter(z_mu_real, z_mu_imag, marker='o', s=26, color='orange')
-            ax.scatter(p_mu_real, p_mu_imag, marker='x', s=26, color='red')
-            plt.show()
+        mpl.rc('text', usetex=True)
+        fig, ax = plt.subplots(dpi=dpi)
+        ax.scatter(n_mu_real, n_mu_imag, marker='x', s=40, linewidth=0.5, color='black')
+        ax.scatter(z_mu_real, z_mu_imag, marker='o', s=40, linewidth=0.5, facecolors='none', edgecolors='black')
+        ax.scatter(p_mu_real, p_mu_imag, marker='x', s=40, linewidth=0.5, color='black')
+        ax.axhline(linewidth=0.5, color='grey', linestyle='--')
+        ax.axvline(linewidth=0.5, color='grey', linestyle='--')
+
+        # plot 5% damping lines
+        xin = np.arange(left, 0, 0.01)
+        yneg = xin / damping
+        ypos = - xin / damping
+
+        ax.plot(xin, yneg, color='grey', linewidth=linewidth, linestyle='--')
+        ax.plot(xin, ypos, color='grey', linewidth=linewidth, linestyle='--')
+        ax.set_xlabel('Real')
+        ax.set_ylabel('Imaginary')
+        ax.set_xlim(left=left, right=right)
+        ax.set_ylim(ymin, ymax)
+
+        plt.show()
+
+        return fig, ax
 
     def dump_results(self):
         """
@@ -237,7 +246,7 @@ class EIG(RoutineBase):
         for prow in range(neig):
             temp_row = partfact[prow, :]
             name_idx = list(temp_row).index(max(temp_row))
-            var_assoc.append(system.varname.unamex[name_idx])
+            var_assoc.append(system.dae.x_name[name_idx])
 
         pf = []
         for prow in range(neig):
@@ -246,7 +255,7 @@ class EIG(RoutineBase):
                 temp_row.append(round(partfact[prow, pcol], 5))
             pf.append(temp_row)
 
-        text.append(system.report.info)
+        text.append('')
         header.append([''])
         rowname.append(['EIGENVALUE ANALYSIS REPORT'])
         data.append('')
@@ -277,8 +286,8 @@ class EIG(RoutineBase):
                 text.append('PARTICIPATION FACTORS [{}/{}]\n'.format(
                     idx + 1, nblock))
                 header.append(numeral[start:end])
-                rowname.append(system.varname.unamex)
+                rowname.append(system.dae.x_name)
                 data.append(pf[start:end])
 
         dump_data(text, header, rowname, data, system.files.eig)
-        logger.info('report saved.')
+        logger.info(f'Report saved to <{system.files.eig}>.')
