@@ -1,34 +1,19 @@
-import os
 import logging
+import os
 
 logger = logging.getLogger(__name__)
 
 
 class FileMan(object):
-    """Define a File Manager class for PowerSystem"""
+    """Define a File Manager class for System"""
 
-    def __init__(self,
-                 case,
-                 input_format=None,
-                 input_path=None,
-                 addfile=None,
-                 config=None,
-                 no_output=False,
-                 dynfile=None,
-                 dump_raw=None,
-                 output_format=None,
-                 output_path='',
-                 output=None,  # base file name for the output
-                 pert=None,
-                 **kwargs):
+    def __init__(self):
         """
         Initialize the output file names.
         For inputs, all absolute paths will be respected; and all relative paths are relative to `input_path`.
 
         case: must be full path to case
 
-        dump_raw: desired simulation result file name
-
         output: desired name for format conversion output
 
         input_path: default path for input files that only contains file name. If `input_path` is not provided,
@@ -36,20 +21,50 @@ class FileMan(object):
 
         output_path: path for output files. Default to current working directory where `andes` is invoked.
         """
-        if isinstance(input_format, str):
-            self.input_format = input_format.lower()
-        else:
-            self.input_format = None
-        if isinstance(output_format, str):
-            self.output_format = output_format.lower()
-        else:
-            self.output_format = None
+        self.input_format = None
+        self.output_format = None
+        self.add_format = None
 
-        if input_path is not None:
-            logger.debug('input_path provided as {}.'.format(input_path))
-            self.case_path = input_path
-        else:
-            self.case_path = os.getcwd()  # default to current directory
+        self.case = None
+        self.case_path = os.getcwd()
+        self.fullname = None
+        self.name = None
+        self.ext = None
+        self.addfile = None
+        self.pert = None
+        self.dynfile = None
+
+        self.output_path = None
+
+        self.no_output = True
+        self.output = None
+        self.dump = None
+        self.lst = None
+        self.eig = None
+        self.npy = None
+        self.prof = None
+        self.prof_raw = None
+
+    def set(self, case=None, **kwargs):
+
+        input_format = kwargs.get('input_format')
+        add_format = kwargs.get('add_format')
+        input_path = kwargs.get('input_path')
+
+        addfile = kwargs.get('addfile')
+        no_output = kwargs.get('no_output')
+        dynfile = kwargs.get('dynfile')
+        output_path = kwargs.get('output_path', os.getcwd())
+        output = kwargs.get('output')  # base file name for the output
+        pert = kwargs.get('pert')
+        dump = kwargs.get('dump')
+        if case is None:
+            return
+
+        self.input_format = input_format
+        self.add_format = add_format
+        self.input_path = input_path if input_path is not None else os.getcwd()
+        self.output_path = os.getcwd() if not output_path else output_path
 
         if os.path.isabs(case):
             self.case = case
@@ -66,8 +81,8 @@ class FileMan(object):
         self.addfile = self.get_fullpath(addfile)
         self.pert = self.get_fullpath(pert)
         self.dynfile = self.get_fullpath(dynfile)
-        self.config = self.get_fullpath(config)
-        self.add_format = None
+        if dump is None:
+            dump = self.name
 
         # use the path where andes is executed as the default output path
         self.output_path = os.getcwd() if not output_path else output_path
@@ -76,27 +91,27 @@ class FileMan(object):
             self.output = None
             self.lst = None
             self.eig = None
-            self.dat = None
-            self.dump_raw = None
+            self.npy = None
             self.prof = None
+            self.prof_raw = None
+            self.dump = None
         else:
             self.no_output = False
             if not output:
                 output = add_suffix(self.name, 'out')
-            if not dump_raw:
-                dump_raw = add_suffix(self.name, 'dm')
             prof = add_suffix(self.name, 'prof')
             eig = add_suffix(self.name, 'eig')
 
             self.lst = os.path.join(self.output_path, output + '.lst')
-            self.dat = os.path.join(self.output_path, output + '.dat')
+            self.npy = os.path.join(self.output_path, output + '.npy')
             self.output = os.path.join(self.output_path, output + '.txt')
 
             self.eig = os.path.join(self.output_path, eig + '.txt')
-            self.dump_raw = os.path.join(self.output_path, dump_raw + '.dm')
             self.prof = os.path.join(self.output_path, prof + '.txt')
+            self.prof_raw = os.path.join(self.output_path, prof + '.prof')
+            self.dump = os.path.join(self.output_path, dump + '.xlsx')
 
-    def get_fullpath(self, fullname=None, relative_to=None):
+    def get_fullpath(self, fullname=None):
         """
         Return the original full path if full path is specified, otherwise
         search in the case file path
